Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1664)

Unified Diff: Source/web/tests/WebInputEventConversionTest.cpp

Issue 1052433003: Allow postponed rail application for touch scrolling - blink side. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Fix broken test. Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/web/tests/WebInputEventConversionTest.cpp
diff --git a/Source/web/tests/WebInputEventConversionTest.cpp b/Source/web/tests/WebInputEventConversionTest.cpp
index 669e9c363ca8e60463c9c3be3ba8145219928ff5..496ceb2eeb344c1e465db2e0c644fd5ab8cea2d7 100644
--- a/Source/web/tests/WebInputEventConversionTest.cpp
+++ b/Source/web/tests/WebInputEventConversionTest.cpp
@@ -269,6 +269,7 @@ TEST(WebInputEventConversionTest, InputEventsScaling)
webGestureEvent.data.scrollUpdate.velocityY = 42;
webGestureEvent.data.scrollUpdate.inertial = true;
webGestureEvent.data.scrollUpdate.preventPropagation = true;
+ webGestureEvent.data.scrollUpdate.railsMode = WebInputEvent::RailsModeVertical;
PlatformGestureEventBuilder platformGestureBuilder(view, webGestureEvent);
EXPECT_EQ(5, platformGestureBuilder.position().x());
@@ -283,6 +284,8 @@ TEST(WebInputEventConversionTest, InputEventsScaling)
EXPECT_EQ(42, platformGestureBuilder.velocityY());
EXPECT_TRUE(platformGestureBuilder.inertial());
EXPECT_TRUE(platformGestureBuilder.preventPropagation());
+ EXPECT_EQ(PlatformEvent::RailsModeVertical,
+ platformGestureBuilder.railsMode());
}
{
@@ -420,9 +423,10 @@ TEST(WebInputEventConversionTest, InputEventsScaling)
{
PlatformGestureEvent platformGestureEvent(PlatformEvent::GestureScrollUpdate, IntPoint(10, 12), IntPoint(20, 22), IntSize(25, 27), 0,
false, false, false, false);
- platformGestureEvent.setScrollGestureData(30, 32, 40, 42, true, true);
+ platformGestureEvent.setScrollGestureData(
+ 30, 32, 40, 42, true, true, PlatformEvent::RailsModeHorizontal);
// FIXME: GestureEvent does not preserve velocityX, velocityY,
// preventPropagation, or inertial. It also fails to scale
// coordinates (x, y, deltaX, deltaY) to the page scale. This
// may lead to unexpected bugs if a PlatformGestureEvent is
// transformed into WebGestureEvent and back.
@@ -439,6 +443,8 @@ TEST(WebInputEventConversionTest, InputEventsScaling)
EXPECT_EQ(0, webGestureBuilder.data.scrollUpdate.velocityY);
EXPECT_FALSE(webGestureBuilder.data.scrollUpdate.inertial);
EXPECT_FALSE(webGestureBuilder.data.scrollUpdate.preventPropagation);
+ EXPECT_EQ(WebInputEvent::RailsModeFree,
+ webGestureBuilder.data.scrollUpdate.railsMode);
}
{
@@ -420,9 +423,10 @@ TEST(WebInputEventConversionTest, InputEventsScaling)
// FIXME: GestureEvent does not preserve velocityX, velocityY,
- // preventPropagation, or inertial. It also fails to scale
+ // preventPropagation, inertial, or railsMode. It also fails to scale
// coordinates (x, y, deltaX, deltaY) to the page scale. This
// may lead to unexpected bugs if a PlatformGestureEvent is

Powered by Google App Engine
This is Rietveld 408576698